{% extends "admin/change_list.html" %}
{% load i18n %}

{% block object-tools %}
<ul class="object-tools">
	<li><a href="{% url gatekeeper_moderate_list %}">Gatekeeper Moderation</a></li>
	{% if has_add_permission %}
	<li><a href="add/{% if is_popup %}?_popup=1{% endif %}" class="addlink">{% blocktrans with cl.opts.verbose_name|escape as name %}Add {{ name }}{% endblocktrans %}</a></li>
	{% endif %}
</ul>
{% endblock %}